.. easy_mpl documentation master file


Welcome to easy_mpl's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

plot
==================
.. automodule:: easy_mpl
   :members: plot

pie
==================
.. automodule:: easy_mpl
   :members: pie

bar_chart
==================
.. automodule:: easy_mpl
   :members: bar_chart

hist
==================
.. automodule:: easy_mpl
   :members: hist

regplot
==================
.. automodule:: easy_mpl
   :members: regplot

imshow
==================
.. automodule:: easy_mpl
   :members: imshow

scatter
==================
.. automodule:: easy_mpl
   :members: scatter

contour
==================
.. automodule:: easy_mpl
   :members: contour

dumbbell
==================
.. automodule:: easy_mpl
   :members: dumbbell_plot

ridge
==================
.. automodule:: easy_mpl
   :members: ridge


parallel_coordinates
====================
.. automodule:: easy_mpl
   :members: parallel_coordinates


taylor_plot
===========
.. automodule:: easy_mpl
   :members: taylor_plot

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
